*************
Distributions
*************

These distributions can be used in any place that
`Nengo distributions
<https://www.nengo.ai/nengo/frontend_api.html#distributions>`_
can be used.

.. default-role:: obj

.. autosummary::

   nengo_extras.dists.Concatenate
   nengo_extras.dists.MultivariateCopula
   nengo_extras.dists.MultivariateGaussian
   nengo_extras.dists.Mixture
   nengo_extras.dists.Tile
   nengo_extras.dists.gaussian_icdf
   nengo_extras.dists.loggaussian_icdf
   nengo_extras.dists.uniform_icdf

.. autoclass:: nengo_extras.dists.Concatenate

.. autoclass:: nengo_extras.dists.MultivariateCopula

.. autoclass:: nengo_extras.dists.MultivariateGaussian

.. autoclass:: nengo_extras.dists.Mixture

.. autoclass:: nengo_extras.dists.Tile

.. autofunction:: nengo_extras.dists.gaussian_icdf

.. autofunction:: nengo_extras.dists.loggaussian_icdf

.. autofunction:: nengo_extras.dists.uniform_icdf
